@@ -1,15 +1,19 @@
-# Copyrights 1995-2010 by Mark Overmeer <perl@overmeer.net>.
+# Copyrights 1995-2019 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
-use strict;
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of the bundle MailTools.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md for Copyright.
+# Licensed under the same terms as Perl itself.
 
 package Mail::Mailer::smtp;
 use vars '$VERSION';
-$VERSION = '2.07';
+$VERSION = '2.21';
 
 use base 'Mail::Mailer::rfc822';
 
+use strict;
+
 use Net::SMTP;
 use Mail::Util qw(mailaddress);
 use Carp;
@@ -23,7 +27,15 @@ sub exec {
     $opt{Debug} ||= 0;
 
     my $smtp = Net::SMTP->new($host, %opt)
-	or return undef;
+        or return undef;
+
+    if($opt{StartTLS})
+    {   $Net::SMTP::VERSION >= 1.28
+            or die "StartTLS requires Net::SMTP 1.28";
+
+        $smtp->starttls
+            or return undef;
+    }
 
     if($opt{Auth})
     {   $smtp->auth(@{$opt{Auth}})
@@ -32,9 +44,7 @@ sub exec {
 
     ${*$self}{sock} = $smtp;
 
-    $smtp->mail(mailaddress);
-    $smtp->mail($opt{From}) if $opt{From};
-
+    $smtp->mail($opt{From} || mailaddress());
     $smtp->to($_) for @$to;
     $smtp->data;
 
@@ -57,11 +67,12 @@ sub epilogue()
 {   my $self = shift;
     my $sock = ${*$self}{sock};
 
-    $sock->dataend;
+    my $ok = $sock->dataend;
     $sock->quit;
 
     delete ${*$self}{sock};
     untie *$self;
+    $ok;
 }
 
 sub close(@)
@@ -71,22 +82,22 @@ sub close(@)
     $sock && fileno $sock
         or return 1;
 
-    $self->epilogue;
+    my $ok = $self->epilogue;
 
     # Epilogue should destroy the SMTP filehandle,
     # but just to be on the safe side.
     $sock && fileno $sock
-        or return 1;
+        or return $ok;
 
     close $sock
         or croak 'Cannot destroy socket filehandle';
 
-    1;
+    $ok;
 }
 
 package Mail::Mailer::smtp::pipe;
 use vars '$VERSION';
-$VERSION = '2.07';
+$VERSION = '2.21';
 
 
 sub TIEHANDLE
